density_1d_normal: computes density for normal univarate random fields in 1d...

View source: R/CharFunc.R

density_1d_normalR Documentation

computes density for normal univarate random fields in 1d between [interv[0], interv[1]]

Description

computes density for normal univarate random fields in 1d between [interv[0], interv[1]]

Usage

density_1d_normal(interv, n2, param, maternParam)

Arguments

interv

- start and endpoint to evalute density

n2

- number of grid points in the interval

param

- (2 x 1) mu, sigma

maternParam

- (3 x 1) nu, tau, kappa


davidbolin/ngme documentation built on Dec. 5, 2023, 11:48 p.m.