polyak.ngme: Post-processing of ngme parameter estimates

View source: R/polyak.ngme.R

polyak.ngmeR Documentation

Post-processing of ngme parameter estimates

Description

Updates the results using Polyak averaging and estimates the MC variance of the parameter estimates.

Usage

polyak.ngme(
  object,
  param = "fixed",
  polyak.rate = 1,
  plot = TRUE,
  burnin.end = NULL
)

Arguments

object

A fitted object returned by the "ngme" function.

param

A character string for which parameter set the averaging should be performed; "fixed" for fixed effects, "random" for time-invariant random effects, "process" for stochastic process, "error" for error term.

polyak.rate

- ([0,1]) how much much of moving average should be used (using weighted average where weight is polyak.rate)

plot

Plot the results or not?

burnin.end

- (int) where from start the variance calc and polyak averaging

See Also

ngme

Examples

  ## Not run: 
  fit <- ngme(...)
  fitted(fit)
  
## End(Not run)


davidbolin/ngme documentation built on Dec. 5, 2023, 11:48 p.m.