spde.A: Computes observation matrix.

View source: R/operator.R

spde.AR Documentation

Computes observation matrix.

Description

A function to compute observation matrix for 1D problems.

Usage

spde.A(loc, x, right.boundary = "neumann", left.boundary = "neumann")

Arguments

loc

A numeric vector of measurement locations.

x

A numeric vector of node locations for the basis functions.

right.boundary

A character string denoting the boundary condition for the right boundary.

left.boundary

A character string denoting the boundary condition for the left boundary.

Details

This is a supplementary function and internally used.

Value

Returns an observation matrix.

See Also

build.A.matrix

Examples

  ## Not run: 
  spde.A(...)
  
## End(Not run)

davidbolin/ngme documentation built on Dec. 5, 2023, 11:48 p.m.