spde.basis: Compute FEM matrices.

View source: R/operator.R

spde.basisR Documentation

Compute FEM matrices.

Description

A function to compute FEM matrices for 1D (longitudinal) problems.

Usage

spde.basis(
  x,
  right.boundary = "neumann",
  left.boundary = "neumann",
  compute.Ce = FALSE,
  name = "matern"
)

Arguments

x

A numeric vector containing node locations.

right.boundary

A character string denoting the boundary condition for the right boundary.

left.boundary

A character string denoting the boundary condition for the left boundary.

Details

This is a supplementary function and internally used.

Value

Returns a list that contains mass matrix, stiffness matrix, and some other related quantities.

See Also

create_matrices_Matern

Examples

  ## Not run: 
  spde.basis(...)
  
## End(Not run)


davidbolin/ngme documentation built on Dec. 5, 2023, 11:48 p.m.