| polyak.ngme | R Documentation |
Updates the results using Polyak averaging and estimates the MC variance of the parameter estimates.
polyak.ngme(
object,
param = "fixed",
polyak.rate = 1,
plot = TRUE,
burnin.end = NULL
)
object |
A fitted object returned by the |
param |
A character string for which parameter set the averaging should be performed;
|
polyak.rate |
- ([0,1]) how much much of moving average should be used (using weighted average where weight is polyak.rate) |
plot |
Plot the results or not? |
burnin.end |
- (int) where from start the variance calc and polyak averaging |
ngme
## Not run:
fit <- ngme(...)
fitted(fit)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.