| spde.A | R Documentation |
A function to compute observation matrix for 1D problems.
spde.A(loc, x, right.boundary = "neumann", left.boundary = "neumann")
loc |
A numeric vector of measurement locations. |
x |
A numeric vector of node locations for the basis functions. |
right.boundary |
A character string denoting the boundary condition for the right boundary. |
left.boundary |
A character string denoting the boundary condition for the left boundary. |
This is a supplementary function and internally used.
Returns an observation matrix.
build.A.matrix
## Not run:
spde.A(...)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.