| spde.basis | R Documentation |
A function to compute FEM matrices for 1D (longitudinal) problems.
spde.basis(
x,
right.boundary = "neumann",
left.boundary = "neumann",
compute.Ce = FALSE,
name = "matern"
)
x |
A numeric vector containing node locations. |
right.boundary |
A character string denoting the boundary condition for the right boundary. |
left.boundary |
A character string denoting the boundary condition for the left boundary. |
This is a supplementary function and internally used.
Returns a list that contains mass matrix, stiffness matrix, and some other related quantities.
create_matrices_Matern
## Not run:
spde.basis(...)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.